==> qmmp_0.5.1.orig.tar.gz: qmmp-0.5.1/src/plugins/General/notifier/translations/notifier_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>通知插件</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>關於通知插件</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Qmmp 通知插件</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>音量：</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Psi Notification</source>
        <translation>PSI 通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source>Enable Psi notification</source>
        <translation>啟用 PSI 通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>桌面通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Delay (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="141"/>
        <source>Transparency:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="321"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="343"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>通知插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>曲目改變通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>音量改變通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="134"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="105"/>
        <source>Notification Template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Font:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Cover size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/General/notifier/translations/notifier_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>通知插件</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>關於通知插件</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Qmmp 通知插件</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>音量：</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Psi Notification</source>
        <translation>PSI 通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="390"/>
        <source>Enable Psi notification</source>
        <translation>啟用 PSI 通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>桌面通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>延遲 (ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Transparency:</source>
        <translation>透明度：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="219"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="241"/>
        <source>Edit template</source>
        <translation>編輯模板</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>通知插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>曲目改變通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>音量改變通知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>Notification Template</source>
        <translation>通知模板</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Font:</source>
        <translation>字體：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>封面大小：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
